# IBM Platform RTM v9.1.4

IBM Platform RTM is an operational dashboard for IBM Platform LSF environments that provides comprehensive workload monitoring, reporting and management. It makes cluster administrators more efficient in their day-to-day activities and provides the information and tools needed to improve cluster efficiency, enable better user productivity, and contain or reduce costs. Unlike other monitoring tools that focus on just one facet of cluster monitoring, Platform RTM provides a complete, integrated monitoring facility that is designed specifically for Platform LSF environments. It enables you to monitor multiple clusters easily and effectively through a single intuitive interface.

Platform RTM provides comprehensive workload monitoring, reporting and management tools to increase productivity, reduce costs and position your employees to work more effectively. Organizations using Platform RTM can benefit from:

- Cluster monitoring and control.
- Flexible charting options.
- Job-level profiling.
- Ability to monitor resource consumption and allocation.
- Automated alerts and exception handling.
- License monitoring: support for FlexNet, Reprise License Manager (RLM) license managers
- IBM Platform LSF performance monitoring

For details on Platform RTM usage and its benefits please visit [RTM Product Page.] [product-page]
More information available at the [IBM Knowledge Center] [platform-rtm-info]

## Prerequisites
This charm makes use of resources, a feature only available in Juju 2.0. During deploy, you will need to specify the installable package(s) required by this charm. Download your licensed IBM Platform RTM packages from the [Passport Advantage Site][passport-rtm]

### System Requirements

IBM Platform RTM supports Ubuntu Trusty (14.04) on the ppc64le hardware
architecture. This charm can only deploy IBM Platform RTM to ppc64le platforms.

### Third party Plugins to be installed along with IBM Platform RTM:
    
    plugin:boost-v4.3-1.tgz
    plugin:clog-v1.6-1.tgz
    plugin:nectar-v0.34-1.tgz
    cacti-plugin-0.8.7g-PA-v2.9.tar.gz
    plugin:settings-v0.71-1.tgz
    plugin:superlinks-v1.4-2.tgz
    adodb492.tgz
    plugin:syslog-v1.22-2.tgz

### Package for Ubuntu on Power (ppc64le):

    rtm-poller-9.1.4-ub14-ppc64le.tar.gz
    rtm-server-9.1.4-ub14-ppc64le.tar.gz

## Deploy

IBM Platform RTM is deployable on Ubuntu Trusty and ppc64le hardware. This is a
subordinate charm which needs MariaDB v5.5 for its deployment, but the default
version from the mariadb charm is v10.1. To install the required version of
mariadb, create a mariadb.yaml file with the following contents:

    mariadb:
      series: "5.5"

Specify this config file during deployment:

juju deploy --config ./mariadb.yaml mariadb

MariaDB may fail to start due to aggressive InnoDB buffer pool allocation
(default is 50% of system memory). If the mariadb charm fails to start,
please set `dataset-size` and resolve the failed unit as shown below:

    juju config mariadb dataset-size="256M"
    juju resolved mariadb/0

For more information on MariaDB deployment and configuration, please visit
[mariadb][mariadb-charm] in the charm store.

With MariaDB deployed, run the following command to deploy IBM Platform RTM:

    juju deploy ibm-platform-rtm \
      --resource ibm_prtm_installer=</path/to/rtm-poller-9.1.4-ub14-ppc64le.tar.gz> \
      --resource ibm_prtm_installer1=</path/to/rtm-server-9.1.4-ub14-ppc64le.tar.gz> \
      --resource ibm_prtm_installers=</path/to/plugin%3Aboost-v4.3-1.tgz> \ 
      --resource ibm_prtm_installers1=</path/to/plugin%3Aclog-v1.6-1.tgz> \ 
      --resource ibm_prtm_installers2=</path/to/plugin%3Anectar-v0.34-1.tgz> \ 
      --resource ibm_prtm_installers3=</path/to/cacti-plugin-0.8.7g-PA-v2.9.tar.gz> \ 
      --resource ibm_prtm_installers4=</path/to/plugin%3Asettings-v0.71-1.tgz> \
      --resource ibm_prtm_installers5=</path/to/plugin%3Asuperlinks-v1.4-2.tgz> \ 
      --resource ibm_prtm_installers6=</path/to/adodb492.tgz> \
      --resource ibm_prtm_installers7=</path/to/rtm/plugin%3Asyslog-v1.22-2.tgz> \

**Note**: This charm requires acceptance of Terms of Use. When deploying from the Charm Store, these terms will be presented to you for your consideration. To accept the terms:

    juju agree ibm-rtm/1

Platform RTM installation begins when a relation is established between Mariadb and IBM Platform RTM.  Create this relation with:

    juju add-relation mariadb ibm-platform-rtm

To remove the relation between MariaDB and Platform-rtm, run the below command (Please remove-relation between Platform-rtm and Mariadb before uninstalling platform RTM)

	juju remove-relation ibm-platform-rtm mariadb

After installing IBM Platform RTM, Use your web browser to start the Platform RTM Console. The URL for the Platform RTM Console is

	http://rtm_host

Here rtm_host is an ip address where Platform RTM is installed. Specify the Platform RTM administrator name and password. The default administrator name is admin, and the default password for this account is admin


<!-- Links -->

[product-page]: http://www-03.ibm.com/systems/platformcomputing/products/lsf/rtm.html

[passport-rtm]: http://www-01.ibm.com/software/passportadvantage/

[license-info]: http://www-03.ibm.com/software/sla/sladb.nsf/searchlis/?searchview&searchorder=4&searchmax=0&query=%28IBM+Platform+RTM%29

[platform-rtm-info]: http://www-01.ibm.com/support/knowledgecenter/SSVMSD_9.1.4/install/install_rtm_ubuntu.dita

[mariadb-charm]: https://jujucharms.com/u/ibm-demo/mariadb/trusty/2


## Third Party Plugins downloadable links:

        wget --restrict-file-names=windows http://docs.cacti.net/_media/plugin:boost-v4.3-1.tgz
        wget --restrict-file-names=windows http://docs.cacti.net/_media/plugin:clog-v1.6-1.tgz
        wget --restrict-file-names=windows http://docs.cacti.net/_media/plugin:nectar-v0.34-1.tgz
        wget http://www.cacti.net/downloads/pia/cacti-plugin-0.8.7g-PA-v2.9.tar.gz
        wget --restrict-file-names=windows http://docs.cacti.net/_media/plugin:settings-v0.71-1.tgz
        wget --restrict-file-names=windows http://docs.cacti.net/_media/plugin:superlinks-v1.4-2.tgz
        wget http://sourceforge.net/projects/adodb/files/adodb-php-4-and-5/adodb-492-for-php/adodb492.tgz
        wget --restrict-file-names=windows http://docs.cacti.net/_media/plugin:syslog-v1.22-2.tgz

## Known Limitations

This charm makes use of Juju features that are only available in version 2.0 or
greater.

## Contact Information

For issues with this charm, please contact [IBM Juju Support Team](mailto:jujusupp@us.ibm.com)
