#!/bin/bash
set -ex
source charms.reactive.sh
ARCHITECTURE=`uname -m`
# Installation Manager install path
PRTM_INSTALL_PATH="/opt/IBM/InstallationManager"
RTM_TOP="/opt/IBM/rtm"

@when_not 'ibm-prtm-prerequisite.install'
function ibm_prtm_prerequisite(){
        juju-log "IBM PLATFORM RTM: Begin Prerequisite Install "
        # To check for supported platform
        if [ "$ARCHITECTURE" != "ppc64le" ]; then
                juju-log "IBM PLATFORM RTM: Unsupported platform. IBM Platform RTM installed with this Charm supports only the POWER LE (ppc64le) platforms."
                status-set blocked "Unsupported Platform"
                retun 0
        fi
        ARCHIVE_DIR=/var/lib/juju/agents/*rtm*/charm/files/archives
        status-set maintenance "Installing prerequisite packages"
        juju-log "IBM PLATFORM RTM : Opening port 80 "
        iptables -A INPUT -p tcp --dport 80 -j ACCEPT
        juju-log "IBM PLATFORM RTM : Port number 80 opened and firewall has been disabled successfully."

        # Install tar
        juju-log "IBM PLATFORM RTM : Download and Install tar"
        apt-get -y install tar
        juju-log "IBM PLATFORM RTM : tar downloaded and installed successfully."
        juju-log "IBM PLATFORM RTM: End Prerequisite Install "
        status-set active "Prerequisite Packages Installed"

        # Get the installable resource
        juju-log "IBM PLATFORM RTM: fetching the ibm_prtm_installer resource"
        status-set maintenance "fetching the ibm_prtm_installer resource"
        cfg_prtm_pkg_name=`resource-get 'ibm_prtm_installer' || echo unavailable`
        cfg_prtm_pkg_name1=`resource-get 'ibm_prtm_installer1' || echo unavailable`
        cfg_prtm_plugin_name=`resource-get 'ibm_prtm_installers' || echo unavailable`
        cfg_prtm_plugin_name1=`resource-get 'ibm_prtm_installers1' || echo unavailable`
        cfg_prtm_plugin_name2=`resource-get 'ibm_prtm_installers2' || echo unavailable`
        cfg_prtm_plugin_name3=`resource-get 'ibm_prtm_installers3' || echo unavailable`
        cfg_prtm_plugin_name4=`resource-get 'ibm_prtm_installers4' || echo unavailable`
        cfg_prtm_plugin_name5=`resource-get 'ibm_prtm_installers5' || echo unavailable`
        cfg_prtm_plugin_name6=`resource-get 'ibm_prtm_installers6' || echo unavailable`
        cfg_prtm_plugin_name7=`resource-get 'ibm_prtm_installers7' || echo unavailable`
        # If we don't have a package, report blocked status; we can't proceed.
        if [ "$cfg_prtm_pkg_name1" = "unavailable" -a "$cfg_prtm_pkg_name" = "unavailable" -a "$cfg_prtm_plugin_name" = "unavailable" -a "$cfg_prtm_plugin_name1" = "unavailable" -a "$cfg_prtm_plugin_name2" = "unavailable" -a "$cfg_prtm_plugin_name3" = "unavailable" -a "$cfg_prtm_plugin_name4" = "unavailable" -a "$cfg_prtm_plugin_name5" = "unavailable" -a "$cfg_prtm_plugin_name6" = "unavailable" -a "$cfg_prtm_plugin_name7" = "unavailable" ]; then
                juju-log "IBM PLATFORM RTM: missing required ibm_prtm_installer resource"
                status-set blocked "missing required ibm_prtm_installer resource"
                return 0
        fi
        set_state 'ibm-prtm-prerequisite.install'
}

check_mariadb_inst(){
        mysql -u root -p`sudo cat /var/lib/mysql/mysql.passwd`
        if [ $? == 0 ]
        then 
                echo "True"
        else
                service mysql start
                mysql -u root -p`sudo cat /var/lib/mysql/mysql.passwd`
                if [ $? == 0 ]; then
                        echo "True"
                else
                        echo "False"
                fi
        fi
}

check_database_inst(){
        db_inst=`check_mariadb_inst`
        if [ $db_inst == False ]; then
                juju-log "IBM PLATFORM RTM : Database is not installed"
                status-set blocked "Database is not installed"
        return 1
        fi
}

@when 'ibm-prtm-prerequisite.install' 
@when_not 'ibm-prtm-database.available'
function mariadb_install_check(){
        check_database_inst
        set_state 'ibm-prtm-database.available'
        status-set active "Mariadb is Installed"
}
#check whethere RTM is installed
is_prtm_installed(){
        if [ -d $RTM_TOP/bin ]; then
                echo "True"
        else
                echo "False"
        fi
}
update_install_file()
{
        juju-log  "IBM PLATFORM RTM : Updation install file for $1 $2 $3"
        if grep -q "# $1" $3
        then
                sed -i "/# $1/c$1='$2'" $3
        else
                sed -i "s|$1.*|$1='$2'|" $3
        fi
}

ibm_prtm_INSTALL()
{
        db_pass=`sudo cat /var/lib/mysql/mysql.passwd`
        mysql_password=$db_pass
        juju-log "IBM PLATFORM RTM : Begin RTM INSTALL"
        prtm_inst=`is_prtm_installed`
        if [ $prtm_inst == False ]; then
                juju-log "IBM PLATFORM RTM : Rtm is not installed"
                cfg_prtm_pkg_name1="/var/lib/juju/agents/*rtm*/resources/ibm_prtm_installer1/*"
                cp $cfg_prtm_pkg_name1 /var/lib/juju/agents/*rtm*/resources
                cfg_prtm_plugin_name="/var/lib/juju/agents/*rtm*/resources/ibm_prtm_installers/*"
                cp $cfg_prtm_plugin_name /var/lib/juju/agents/*rtm*/resources
                cfg_prtm_plugin_name1="/var/lib/juju/agents/*rtm*/resources/ibm_prtm_installers1/*"
                cp $cfg_prtm_plugin_name1 /var/lib/juju/agents/*rtm*/resources
                cfg_prtm_plugin_name2="/var/lib/juju/agents/*rtm*/resources/ibm_prtm_installers2/*"
                cp $cfg_prtm_plugin_name2 /var/lib/juju/agents/*rtm*/resources
                cfg_prtm_plugin_name3="/var/lib/juju/agents/*rtm*/resources/ibm_prtm_installers3/*"
                cp $cfg_prtm_plugin_name3 /var/lib/juju/agents/*rtm*/resources
                cfg_prtm_plugin_name4="/var/lib/juju/agents/*rtm*/resources/ibm_prtm_installers4/*"
                cp $cfg_prtm_plugin_name4 /var/lib/juju/agents/*rtm*/resources
                cfg_prtm_plugin_name5="/var/lib/juju/agents/*rtm*/resources/ibm_prtm_installers5/*"
		cp $cfg_prtm_plugin_name5 /var/lib/juju/agents/*rtm*/resources
		cfg_prtm_plugin_name6="/var/lib/juju/agents/*rtm*/resources/ibm_prtm_installers6/*"
		cp $cfg_prtm_plugin_name6 /var/lib/juju/agents/*rtm*/resources
                cfg_prtm_plugin_name7="/var/lib/juju/agents/*rtm*/resources/ibm_prtm_installers7/*"
                cp $cfg_prtm_plugin_name7 /var/lib/juju/agents/*rtm*/resources
                cd /var/lib/juju/agents/*rtm*/resources 
  
                juju-log " IBM PLATFORM RTM : Extracting the Installer packages"           
                res_name=`resource-get 'ibm_prtm_installer'`
                tar -zxvf $res_name
                if [ $? != 0 ]; then
                        juju-log "IBM PLATFORM RTM : Unable to extract the RTM installer package content. Verify whether the package is corrupt."
                        # Remove corrupt archive file
                        rm *poller*.tar.gz
                        return 0
                 else 
                        juju-log "IBM PLATFORM RTM : installer packages extracted successfully"
                        juju-log "IBM PLATFORM RTM : Platform RTM will be installed if you run (juju add-relation mariadb platform-rtm) command."
                        status-set active "IBM PLATFORM RTM : installer packages extraced"

                 fi
                 rm -f /var/lib/mysql/ib_logfile*
                 service mysql stop
                 rm -f /var/lib/mysql/ibdata*
                 cd /var/lib/juju/agents/*rtm*/resources/NOOSS/ppc64
                 juju-log "IBM PLATFORM RTM : Installing Platformat RTM"
                 update_install_file "OPTIMIZE_MYSQL" "N" "install.config"
                 update_install_file "DB_PASSWORD" "$mysql_password" "install.config"
                 #Running install command
                 juju-log "IBM PLATFORM RTM: Running installation command for platform RTM"
                sed -i '/LAPApp.jar/,+8d' rtm_install.sh
                sed -i 's/rsyslog-mysql//g' rtm_install.sh
                ln -sf bash /bin/sh
                echo "Y" | sh rtm_install.sh -f install.config
                if [ $? == 0 ]; then
                        juju-log "IBM PLATFORM RTM :  installed successfully"
                        status-set active "RTM Installed"
                else
                        juju-log "IBM PLATFORM RTM : Error while installing IBM pLATFORM rtm"
                        status-set blocked "Error while installing IBM Platform RTM"
                        return 1
                fi
                service lsfpollerd status; service licpollerd status; service advocate status
                if [ $? == 0 ]; then
                        juju-log "IBM PLATFORM RTM : RTM installed successfully and RTM services are up and running!"
                else
                        juju-log "IBM PLATFROM RTM : Error while installing IBM Platform RTM"
                        status-set blocked "Error"
                        return 1
                fi
         else
                juju-log "IBM PLATFORM RTM : RTM IS ALREADY INSTALLED"
         fi
}

@when 'ibm-prtm-database.available'
@when_not 'ibm-prtm.available'
function ibm_prtm_install(){
         ibm_prtm_INSTALL
         set_state 'ibm-prtm.available'
         status-set active "ibm platform rtm installed"
}
reactive_handler_main
